/****************************************************************************/
/* External Definitions                 */

{pdsDefinitions.i}

/****************************************************************************/
/* Procedure &Scoped-Define           */

&SCOPED-DEFINE DbNameFormat     "X(12)"
&SCOPED-DEFINE TableNameFormat  "X(32)"
&SCOPED-DEFINE IndexNameFormat  "X(17)"
&SCOPED-DEFINE FieldNameFormat  "X(32)"
&SCOPED-DEFINE DataTypeFormat   "X(15)"

&SCOPED-DEFINE FrameWidth       300

/****************************************************************************/
/* Procedure Parameters                 */

DEFINE INPUT PARAMETER DATASET FOR pdsSchema.
DEFINE INPUT PARAMETER chBaseDirectory AS CHARACTER NO-UNDO.

/****************************************************************************/
/* Do Work                              */

ASSIGN 
    chBaseDirectory = TRIM(chBaseDirectory, "/~\")
    .

OUTPUT TO VALUE(chBaseDirectory + "/" + "db.out").

FOR EACH ttDb
    NO-LOCK 
    :

    DISPLAY ttDb._db-name       FORMAT {&DbNameFormat}
        WITH FRAME f-Db 
        DOWN 
        STREAM-IO 
        WIDTH {&FrameWidth}
        .

END.

OUTPUT CLOSE.

OUTPUT TO VALUE(chBaseDirectory + "/" + "table.out").

FOR EACH ttFile
    NO-LOCK 
    :

    DISPLAY ttFile._db-name     FORMAT {&DbNameFormat}
            ttFile._file-name   FORMAT {&TableNameFormat}
            ttFile._desc        VIEW-AS EDITOR SIZE 60 BY 1
        WITH FRAME f-file
        DOWN 
        STREAM-IO 
        WIDTH {&FrameWidth}
        .

END.

OUTPUT CLOSE.

OUTPUT TO VALUE(chBaseDirectory + "/" + "field.out").

FOR EACH ttField
    NO-LOCK 
    BREAK BY ttField._db-name 
          BY ttField._file-name 
          BY ttField._field-name 
    :

    DISPLAY ttField._db-name    FORMAT {&DbNameFormat}      WHEN FIRST-OF(ttfield._db-name) OR 
                                                                 FIRST-OF(ttfield._file-name)
            ttField._file-name  FORMAT {&TableNameFormat}   WHEN FIRST-OF(ttfield._file-name)
            ttField._field-name FORMAT "X(32)"
            ttField._data-type  FORMAT "X(10)"
            ttField._desc       VIEW-AS EDITOR SIZE 60 BY 1
        WITH FRAME f-field
        DOWN 
        STREAM-IO 
        WIDTH {&FrameWidth}
        .
    IF LAST-OF(ttField._file-name) THEN
        PUT UNFORMATTED     SKIP
            FILL("-", 132)  SKIP
        .

END.

OUTPUT CLOSE.

OUTPUT TO VALUE(chBaseDirectory + "/" + "index.out").

FOR EACH ttIndex
    NO-LOCK 
    BREAK BY ttIndex._db-name 
          BY ttIndex._file-name
          BY ttIndex._index-name
    :

    DISPLAY ttIndex._db-name        FORMAT {&DbNameFormat}      WHEN FIRST-OF(ttIndex._file-name)
            ttIndex._file-name      FORMAT {&TableNameFormat}   WHEN FIRST-OF(ttIndex._file-name)
            ttIndex._index-name     FORMAT {&IndexNameFormat}
            ttIndex._unique         FORMAT "U/ "                    COLUMN-LABEL "Unq"
            
            CAN-FIND(ttFile 
                    WHERE ttFile._db-name     = ttIndex._db-name 
                      AND ttFile._file-name   = ttIndex._file-name 
                      AND ttFile._prime-index = ttIndex._index-recid
                     ) COLUMN-LABEL "Pri" FORMAT "P/ "
        
        WITH FRAME f-index
            DOWN 
            STREAM-IO 
            WIDTH {&FrameWidth}
            .

    IF LAST-OF(ttIndex._file-name) THEN
        VIEW FRAME f-null.
END.

OUTPUT CLOSE.

OUTPUT TO VALUE(chBaseDirectory + "/" + "indexfield.out").

FOR EACH ttIndexField
    NO-LOCK 
    BREAK BY ttIndexField._db-name       
          BY ttIndexField._file-name     
          BY ttIndexField._index-name    
          BY ttIndexField._index-seq
    :
    
    FIND ttIndex 
      WHERE ttIndex._Db-name    = ttIndexField._db-name       
        AND ttIndex._File-name  = ttIndexField._File-name
        AND ttIndex._Index-name = ttIndexField._Index-name
      NO-LOCK NO-ERROR.
      
    DISPLAY ttIndexField._db-name       FORMAT {&DbNameFormat}      WHEN FIRST-OF(ttIndexField._file-name)
            ttIndexField._file-name     FORMAT {&TableNameFormat}   WHEN FIRST-OF(ttIndexField._file-name)
            
            CAN-FIND(ttFile 
                    WHERE ttFile._db-name     = ttIndex._db-name 
                      AND ttFile._file-name   = ttIndex._file-name 
                      AND ttFile._prime-index = ttIndex._index-recid
                     )                  FORMAT "P/ "                WHEN FIRST-OF(ttIndexField._index-name) AND 
                                                                         AVAILABLE (ttIndex)
                                                                    COLUMN-LABEL "P" 

            ttIndex._unique             FORMAT "U/ "                WHEN FIRST-OF(ttIndexField._index-name) AND 
                                                                         AVAILABLE (ttIndex)
                                                                         COLUMN-LABEL "U"
            ttIndexField._index-name    FORMAT {&IndexNameFormat}   WHEN FIRST-OF(ttIndexField._index-name)
            ttIndexField._index-seq     FORMAT ">9"                 COLUMN-LABEL "#"
            ttIndexField._ascending     FORMAT "+/-"                COLUMN-LABEL "S!T"
            ttIndexField._field-name    FORMAT {&FieldNameFormat}
            ttIndexField._data-type     FORMAT {&DataTypeFormat}

        WITH FRAME f-indexfield
          DOWN 
          STREAM-IO 
          WIDTH {&FrameWidth}
          .

    IF LAST-OF(ttIndexField._file-name) THEN
        VIEW FRAME f-null.
    ELSE
        IF LAST-OF(ttIndexField._index-name) THEN
            DOWN 1 WITH FRAME f-indexfield.


END.

OUTPUT CLOSE.
